Index — Static Media Manager v0.4 documentation

Static Media Manager v0.4 documentation

# Index

- Table of Contents
- index
  modules

# Index

Symbols | C | S

## Symbols

-c, --compresscss command line option -j, --compressjs command line option | -p, --purge command line option

## C

combine_files() (in module staticmediamgr.utils) command line option -c, --compresscss -j, --compressjs -p, --purge | compress_copy() (in module staticmediamgr.utils) copy() (in module staticmediamgr.utils) copy_app_media() (in module staticmediamgr.utils) copydir() (in module staticmediamgr.utils)

## S

staticmediamgr.utils (module) |